.*: Assembler messages:
.*:8: Error: relocation overflow
.*:9: Error: relocation overflow
.*:10: Error: relocation overflow
.*:11: Error: relocation overflow
.*:12: Error: relocation overflow
.*:13: Error: relocation overflow
.*:14: Error: relocation overflow
.*:15: Error: relocation overflow
.*:16: Error: relocation overflow
.*:17: Error: relocation overflow
