#objdump: -d
#name:    Expressions in OPR direct submode
#source:  opr-expr.s

dump.o:     file format elf32-s12z


Disassembly of section .text:

00000000 <.text>:
   0:	01          	nop
   1:	01          	nop
   2:	bc 12 39    	clr.b 4665
