SCRIPT_NAME=elf
TEMPLATE_NAME=elf32
OUTPUT_FORMAT="elf32-pru"
LITTLE_OUTPUT_FORMAT="elf32-pru"
SCRIPT_NAME=pru

ARCH=pru
MACHINE=
MAXPAGESIZE="CONSTANT (MAXPAGESIZE)"
COMMONPAGESIZE="CONSTANT (COMMONPAGESIZE)"
EMBEDDED=yes

TEXT_ORIGIN=0x20000000
TEXT_LENGTH=8K
DATA_ORIGIN=0x0
DATA_LENGTH=8K

ENTRY=_start
EXTRA_EM_FILE=pruelf
