
Attribute Section: gnu
File Attributes
  Tag_GNU_MIPS_ABI_FP: Hard float \(double precision\)

MIPS ABI Flags Version: 0

ISA: MIPS.*
GPR size: .*
CPR1 size: .*
CPR2 size: 0
FP ABI: Hard float \(double precision\)
ISA Extension: .*
ASEs:
	MIPS16 ASE
FLAGS 1: 00000000
FLAGS 2: 00000000

Primary GOT:
 Canonical gp value: 00057ff0

 Reserved entries:
   Address     Access  Initial Purpose
  00050000 -32752\(gp\) 00000000 Lazy resolver
  00050004 -32748\(gp\) 80000000 Module pointer \(GNU extension\)

 Local entries:
   Address     Access  Initial
  00050008 -32744\(gp\) 00040000
  0005000c -32740\(gp\) 00040409
  00050010 -32736\(gp\) 0004040d
  00050014 -32732\(gp\) 00000000

 Global entries:
   Address     Access  Initial Sym\.Val\. Type    Ndx Name
  00050018 -32728\(gp\) 00040574 00040574 FUNC      7 used6
  0005001c -32724\(gp\) 00040598 00040598 FUNC      7 used7
  00050020 -32720\(gp\) 00040550 00040550 FUNC      7 used5
  00050024 -32716\(gp\) 0004052c 0004052c FUNC      7 used4

