.*: Assembler messages:
.*:14: Error: jump to misaligned address \(0x10e1\)
.*:16: Error: jump to misaligned address \(0x10e1\)
.*:18: Error: jump to misaligned address \(0x10e2\)
.*:20: Error: jump to misaligned address \(0x10e2\)
.*:22: Error: jump to misaligned address \(0x10e3\)
.*:24: Error: jump to misaligned address \(0x10e3\)
.*:30: Error: jump to misaligned address \(0x10e5\)
.*:32: Error: jump to misaligned address \(0x10e5\)
.*:34: Error: jump to misaligned address \(0x10e6\)
.*:36: Error: jump to misaligned address \(0x10e6\)
.*:38: Error: jump to misaligned address \(0x10e7\)
.*:40: Error: jump to misaligned address \(0x10e7\)
.*:46: Error: JALX to a symbol in the same ISA mode
.*:50: Error: JALX to a symbol in the same ISA mode
.*:52: Error: jump to misaligned address \(0x10f2\)
.*:54: Error: JALX to a symbol in the same ISA mode
.*:58: Error: JALX to a symbol in the same ISA mode
.*:60: Error: jump to misaligned address \(0x10f5\)
.*:62: Error: JALX to a symbol in the same ISA mode
.*:64: Error: jump to misaligned address \(0x10f6\)
.*:66: Error: JALX to a symbol in the same ISA mode
.*:68: Error: jump to misaligned address \(0x10f7\)
.*:70: Error: JALX to a symbol in the same ISA mode
