#source: property-x86-ibt.s
#source: property-x86-3.s
#as: --32
#ld: -r -melf_i386
#readelf: -n

Displaying notes found in: .note.gnu.property
  Owner                 Data size	Description
  GNU                  0x00000018	NT_GNU_PROPERTY_TYPE_0
      Properties: x86 ISA used: i486, 586, SSE2, SSE3
	x86 ISA needed: 586, SSE, SSE3, SSE4_1
