.*: Assembler messages:
.*:5: Error: operand 4 out of range `copyw \$2,\$2,0,0'
.*:6: Error: operand 4 out of range `copyw \$2,\$2,0,5'
.*:7: Error: operand 3 out of range `copyw \$2,\$2,-16,1'
.*:8: Error: operand 3 out of range `copyw \$2,\$2,-15,1'
.*:9: Error: operand 3 out of range `copyw \$2,\$2,-1,1'
.*:10: Error: operand 3 out of range `copyw \$2,\$2,1,1'
.*:11: Error: operand 3 out of range `copyw \$2,\$2,15,1'
.*:12: Error: operand 3 out of range `copyw \$2,\$2,512,1'
.*:13: Error: invalid operands `copyw \$2,\$1,0,1'
.*:14: Error: invalid operands `copyw \$2,\$8,0,1'
.*:15: Error: invalid operands `copyw \$1,\$2,0,1'
.*:16: Error: invalid operands `copyw \$8,\$2,0,1'
.*:17: Error: operand 3 out of range `copyw \$2,\$2,1,0'
.*:18: Error: invalid operands `copyw \$8,\$1,1,0'
.*:19: Error: operand 4 out of range `ucopyw \$2,\$2,0,0'
.*:20: Error: operand 4 out of range `ucopyw \$2,\$2,0,5'
.*:21: Error: operand 3 out of range `ucopyw \$2,\$2,-16,1'
.*:22: Error: operand 3 out of range `ucopyw \$2,\$2,-15,1'
.*:23: Error: operand 3 out of range `ucopyw \$2,\$2,-1,1'
.*:24: Error: operand 3 out of range `ucopyw \$2,\$2,1,1'
.*:25: Error: operand 3 out of range `ucopyw \$2,\$2,15,1'
.*:26: Error: operand 3 out of range `ucopyw \$2,\$2,512,1'
.*:27: Error: invalid operands `ucopyw \$2,\$1,0,1'
.*:28: Error: invalid operands `ucopyw \$2,\$8,0,1'
.*:29: Error: invalid operands `ucopyw \$1,\$2,0,1'
.*:30: Error: invalid operands `ucopyw \$8,\$2,0,1'
.*:31: Error: operand 3 out of range `ucopyw \$2,\$2,1,0'
.*:32: Error: invalid operands `ucopyw \$8,\$1,1,0'
