.*: Assembler messages:
.*:17: Warning: extended instruction in a branch delay slot
.*:19: Warning: extended instruction in a branch delay slot
.*:21: Warning: macro instruction expanded into multiple instructions in a branch delay slot
.*:23: Warning: macro instruction expanded into multiple instructions in a branch delay slot
