; Test ARC specific assembler warnings
;
; { dg-do assemble { target arc*-*-* } }

	b.d foo
	mov r0,256	

	j.d foo		; { dg-warning "inappropriate arguments for opcode" "inappropriate arguments for opcode" }
	mov r0,r1

foo:

